/***This program calculates the relation between same store sales and survey responses.***/
/***library. denotes the library name where the files are stores. This needs to be changed to match the users library structure.***/


/***Using Chamber of Commerce responses***/

/***Variables:
state: state in which located
county: county in which located
totpop: population of county
bks_cnty: number of banks in county
stores: number stores in county
sls_grth: same store sales growth
lns_fl_cnty: loans of banks that failed
lns29_cnty: loans of all banks in the county in 1929
dep33_cnty: deposits of banks in the county in 1933
dep29_cnty: deposits of banks in the county in 1929    
coc_need: proportion of Chambers of Commerce reporting a credit need
unemp: unemployment rate
agshr2: proportion of county income from agriculture
***/

    
data coc_reg1; set library.coc_reg1;
if bks_cnty>0;

if state='WI' then wisc=1; else wisc=0;
if state='NY' then ny=1; else ny=0;
if state='NC' then nc=1; else nc=0;
if state='TX' then tx=1; else tx=0;

if lns_fl_cnty=. then lns_fl_cnty=0;
if dep33_cnty=. then dep33_cnty=0;

fail_shr=100*lns_fl_cnty/lns29_cnty;
dep_chg=100*((dep33_cnty/dep29_cnty)-1);
if abs(dep_chg)=<100;


lrgnpop=log(totpop/1000);
lrbks=log(bks_cnty);
if bks_cnty>=3;

if county='Wilson' and state='NC' then delete;
if county in('Kings','New York','Queens') and state='NY' then delete;
if fail_shr~=.;

proc sort; by county state;
proc means noprint; var coc_need sls_grth stores unemp lrgnpop agshr2 wisc nc
    ny tx;
    by county state; 
 output out=coc_sales mean=coc_need sls_grth stores unemp lrgnpop agshr2 wisc nc ny tx;
run;

data coc_sales2; set coc_sales;
lstores=log(stores);
if sls_grth>-75;
    proc reg; model sls_grth=coc_need /*lstores unemp agshr2*/ wisc nc ny tx;
      
proc means; var sls_grth coc_need; where stores>19;
run;


/***Regressions using the bank survey responses***/

/***Variables:
state: state in which located
county: county in which located
totpop: population of county
bks_cnty: number of banks in county
stores: number stores in county
sls_grth: same store sales growth
lns_fl_cnty: loans of banks that failed
lns29_cnty: loans of all banks in the county in 1929
dep33_cnty: deposits of banks in the county in 1933
dep29_cnty: deposits of banks in the county in 1929    
bk_need: proportion of banks reporting a credit need
unemp: unemployment rate
agshr2: proportion of county income from agriculture
***/

    
data bank_reg1; set library.bank_reg1;

lrgnpop=log(totpop/1000);
lrbks=log(bks_cnty);
if state='WI' then wisc=1; else wisc=0;
if state='NY' then ny=1; else ny=0;
if state='OH' then oh=1; else oh=0;
if state='NC' then nc=1; else nc=0;
if state='TX' then tx=1; else tx=0;

lrgnpop=log(totpop/1000);
lrbks=log(bks_cnty);

if lns_fl_cnty=. then lns_fl_cnty=0;
if dep33_cnty=. then dep33_cnty=0;

fail_shr=100*lns_fl_cnty/lns29_cnty;
dep_chg=100*((dep33_cnty/dep29_cnty)-1);
if abs(dep_chg)<101;

if bks_cnty>2;
if county='Wilson' and state='NC' then delete;
if county in('Kings','New York','Queens') and state='NY' then delete;
if fail_shr~=.;

proc sort; by county state;
proc means noprint; var bk_need sls_grth stores unemp lrgnpop agshr2 wisc nc
    ny tx; by county state; 
 output out=bk_sales mean=bk_need sls_grth stores unemp lrgnpop agshr2 wisc nc
     ny tx;
run;

data bk_sales2; set bk_sales;

lstores=log(stores);

if sls_grth>-75;
    proc reg; model sls_grth=bk_need /*lstores unemp agshr2*/ wisc nc ny tx;

proc means; var sls_grth bk_need;
run;

