/********************************************************

Stata code to replicate Tables 3 - 13 
in "Credit Availability and the Collapse of the Banking Sector in the 1930s"
by Mark Carlson and Jonathan Rose

Data files needed:
1) county_regfile_bank (file with bank survey results)
2) county_regfile_coc  (file with chamber of commerce survey results)

********************************************************/


#delimit ;





/********************************************************
Regressions using bank survey results
	Table 3 (upper half)
	Table 4
	Table 5
	Table 10, upper half
	Table 11 
	Table 13

********************************************************/

use county_regfile_bank;		
       
local controls "gest33 gva33  g_rtl   urate33 g_mfg cropdev  crop_va  assets_output lbanks29 conc sfed_assets  wi nc ny tx";

        
	/* Table 3 - upper half -  and Table 4*/
					
			    bys state county: keep if _n==1;
			    
			    matrix results = (0 \0 \0 \0 \0);
			    local varlist  sloan gdep liq riskw 
			                   `controls' ;
			    foreach var of local varlist{;
			        ttest `var' , by(nb_county_bank);
			        matrix results_`var' = (r(mu_1) \ r(sd_1) \ r(mu_2) \ r(sd_2) \ r(p));
			        matrix results = results , results_`var';
			    };
			    matrix results = results[1..., 2...];
			    matrix colnames results =  `varlist';
			    matrix list results;
			    
			    clear;
			    
			    svmat results, names(col);
			    xpose, clear varname;
			    order _varname;
			    rename v1 mean_no;
			    rename v2 sd_no;
			    rename v3 mean_yes;
			    rename v4 sd_yes;
			    rename v5 pvalue;
				  list;
        
					clear;

		    
        
        
        
        
  /* Table 5 */

use county_regfile_bank;		
        
            logit need sloan `controls' [pw=weight], cluster(cgroup);
            mfx;
    
            logit need gdep `controls' [pw=weight], cluster(cgroup);
            mfx;
 
            logit need liq `controls' [pw=weight], cluster(cgroup);
            mfx;
 
            logit need riskw `controls' [pw=weight], cluster(cgroup);
            mfx;
 
		/* Table 10, upper half */
        
            logit need  sloan gdep `controls' [pw=weight], cluster(cgroup);
            mfx;
            testparm sloan gdep;

            logit need sloan liq `controls' [pw=weight], cluster(cgroup);
            mfx;
            testparm sloan liq;

            logit need gdep liq `controls' [pw=weight], cluster(cgroup) ;
            mfx;
            testparm gdep liq;

            logit need sloan gdep liq  `controls' [pw=weight], cluster(cgroup) ;
            mfx;
            testparm sloan gdep liq ;




  /* Table 11 */        
  
			* line 1 - low failure rates;

          gen newcond = cond(sloan<.11,1,0);
          bys state county: egen responses_new = total(newcond);
          gen weight_new = 1/responses_new;

          logit need gdep `controls' if sloan<.11 [pw=weight_new], cluster(cgroup);
          mfx;
		  
		  * line 2 - low deposit contraction;

          gen newcond2 = cond(gdep>-.34,1,0);
          bys state county: egen responses_new2 = total(newcond2);
          gen weight_new2 = 1/responses_new2;


          logit need sloan `controls' if gdep>-.34 [pw=weight_new2], cluster(cgroup);
          mfx;


          logit need liq `controls' if gdep>-.34 [pw=weight_new2], cluster(cgroup);
          mfx;


			* line 3 - mfg at least 35 output;

          drop responses_new weight_new newcond;
          gen newcond = cond(crop_va<.65,1,0);
          bys state county: egen responses_new = total(newcond);
          gen weight_new = 1/responses_new;

          logit need sloan `controls' if crop_va<.65 [pw=weight_new], cluster(cgroup);
          mfx;

          logit need gdep `controls' if crop_va<.65 [pw=weight_new], cluster(cgroup);
          mfx;

          logit need liq `controls' if crop_va<.65 [pw=weight_new], cluster(cgroup);
          mfx;


      * line 4 - 10 banks;

          drop responses_new weight_new newcond;
          gen newcond = cond(banks1929>9,1,0);
          bys state county: egen responses_new = total(newcond);
          gen weight_new = 1/responses_new;
      
          logit need sloan `controls' if banks1929>9 [pw=weight_new], cluster(cgroup);
          mfx;

          logit need gdep `controls' if banks1929>9 [pw=weight_new], cluster(cgroup);
          mfx;
          
          logit need liq `controls' if banks1929>9 [pw=weight_new], cluster(cgroup);
          mfx;

       *  line 5 - reweight;

      
          logit need sloan `controls'  [pw=svwght3], cluster(cgroup);
          mfx;

          logit need gdep `controls' if banks1929>9 [pw=svwght3], cluster(cgroup);
          mfx;
          
          logit need liq `controls' if banks1929>9 [pw=svwght3], cluster(cgroup);
          mfx;


      * line 6 - coc counties;

          drop responses_new weight_new newcond;
          gen newcond = cond(match==1,1,0);
          bys state county: egen responses_new = total(newcond);
          gen weight_new = 1/responses_new;
      
          logit need  sloan `controls' [pw=weight_new] if match==1, cluster(cgroup);
          mfx;

          logit need  gdep `controls' [pw=weight_new] if match==1, cluster(cgroup);
          mfx;

          logit need  liq `controls' [pw=weight_new] if match==1, cluster(cgroup);
          mfx;

      * line 7 - unweighted;
          logit need sloan `controls'  , cluster(cgroup);
          mfx;

          logit need gdep `controls'  , cluster(cgroup);
          mfx;

          logit need liq `controls'  , cluster(cgroup);
          mfx;

      * line 8 - borderline removed;

          drop responses_new weight_new newcond;
          gen newcond = cond(tough_call~=1,1,0);
          bys state county: egen responses_new = total(newcond);
          gen weight_new = 1/responses_new;

          logit need  sloan `controls' if tough_call~=1 [pw=weight_new], cluster(cgroup);
          mfx;

          logit need  gdep `controls' if tough_call~=1 [pw=weight_new], cluster(cgroup);
          mfx;

          logit need  liq `controls' if tough_call~=1 [pw=weight_new], cluster(cgroup);
          mfx;

  /* Table 13 */ 

			* line 1 - neighboring county effects;
			
            gen border = cond(bsloan~=.,1,0);
            replace bsloan = 0 if bsloan==.;
            replace bgdep = 0 if bgdep ==.;
            replace bliq = 0 if bliq==.;
            
            logit need  sloan bsloan border `controls' [pw=weight] , cluster(cgroup);
            mfx;
			
			* line 2 - early vs. late failures;

            logit need  sloan_p1 sloan_p2 `controls' [pw=weight] , cluster(cgroup);
            mfx;
            testparm sloan_p1 sloan_p2;










/********************************************************
IV Regressions using bank survey results
	Table 6
	Table 7
	Table 8
********************************************************/


clear;
use county_regfile_bank;

bys state county: keep if _n==1;

		* generate ivs;
		
		  gen meanassets = (assets1929/10^6)/banks1929;
		  gen pr_nw = pr1929/nw1929;
		  gen nw_d = nw1929/totdep1929;
		  gen aggb_d = bills1929/totdep1929;
		
		local controls "gest33 gva33 g_rtl urate33 g_mfg cropdev  crop_va  assets_output lbanks29 conc sfed_assets oh tx nc wi";
		local ivlist "meanassets pr_nw nw_d aggb_d";





/* Table 6*/

    probit nb_county_bank sloan `controls', r ;
    mfx;
   
    ivprobit nb_county_bank (sloan = `ivlist') `controls' ,  first r;
    
    mfx, predict(p);

    reg sloan  `controls' `ivlist', r;
    testparm `ivlist';



/* Table 7 */

    probit nb_county_bank gdep `controls', r ;
    mfx;

    ivprobit nb_county_bank (gdep = `ivlist') `controls' ,  first ;
    
    mfx, predict(p);
    
    reg gdep  `controls' `ivlist', r;
    testparm `ivlist';

/* Table 8*/


    probit nb_county_bank liq `controls', r ;
    mfx;

    ivprobit nb_county_bank (liq = `ivlist') `controls' ,  first ;
    
    mfx, predict(p);
    
    reg liq  `controls' `ivlist', r;
    testparm `ivlist';

/* Table 12 */

		* line 1 - low failure rates;

    ivprobit nb_county_bank (gdep =`ivlist') `controls' if sloan<.11;
    mfx, predict(p);
    
	  * line 2 - low deposit contraction;

    ivprobit nb_county_bank (sloan =`ivlist') `controls' if gdep>-.34 ;
    mfx, predict(p);

    ivprobit nb_county_bank (liq =`ivlist') `controls' if gdep>-.34 ;
    mfx, predict(p);


 	  *line 3 -  mfg at least 35 output;

    ivprobit nb_county_bank (sloan=`ivlist') `controls' if crop_va<.65;
    mfx, predict(p);

    ivprobit nb_county_bank (gdep=`ivlist') `controls' if crop_va<.65;
    mfx, predict(p);

    ivprobit nb_county_bank (liq=`ivlist') `controls' if crop_va<.65;
    mfx, predict(p);

	  * line 4 - 10 banks;
    ivprobit nb_county_bank (sloan=`ivlist') `controls' if banks1929>9;
    mfx, predict(p);

    ivprobit nb_county_bank (gdep=`ivlist') `controls' if banks1929>9;
    mfx, predict(p);

    ivprobit nb_county_bank (liq=`ivlist') `controls' if banks1929>9;
    mfx, predict(p);

  
	  * line 5 - coc counties;

    ivprobit nb_county_bank (sloan=`ivlist') `controls' if match==1;
    mfx, predict(p);

    ivprobit nb_county_bank (gdep=`ivlist') `controls' if match==1;
    mfx, predict(p);

    ivprobit nb_county_bank (liq=`ivlist') `controls' if match==1;
    mfx, predict(p);


		* line 6 - borderline removed;

    ivprobit notough (sloan=`ivlist') `controls';
    mfx, predict(p);

    ivprobit notough (gdep=`ivlist') `controls';
    mfx, predict(p);

    ivprobit notough (liq=`ivlist') `controls' ;
    mfx, predict(p);

    


/********************************************************
Regressions using COC survey results
	Table 3, lower half
	Table 9
	Table 10, lower half

********************************************************/
clear;
use county_regfile_coc;

local controls "gest33 gva33   g_rtl   urate33 g_mfg cropdev  crop_va  assets_output lbanks29 conc sfed_assets  wi nc ny tx";


               
		/* Table 3 - lower half */
		
		    bys state county: keep if _n==1;
		    
		    matrix results = (0 \0 \0 \0 \0);
		    local varlist  sloan gdep liq  riskw 
		                   `controls' ;
		    foreach var of local varlist{;
		        ttest `var' , by(nb_county_coc);
		        matrix results_`var' = (r(mu_1) \ r(sd_1) \ r(mu_2) \ r(sd_2) \ r(p));
		        matrix results = results , results_`var';
		    };
		    matrix results = results[1..., 2...];
		    matrix colnames results =  `varlist';
		    matrix list results;
		    
		    clear;
		    
		    svmat results, names(col);
		    xpose, clear varname;
		    order _varname;
		    rename v1 mean_no;
		    rename v2 sd_no;
		    rename v3 mean_yes;
		    rename v4 sd_yes;
		    rename v5 pvalue;
				list;		



				clear;


	/* Table 9 */
  use county_regfile_coc;


	
        logit need sloan `controls' [pw=weight], cluster(cgroup);
        mfx;

        logit need gdep `controls' [pw=weight], cluster(cgroup);
        mfx;

        logit need liq `controls' [pw=weight], cluster(cgroup);
        mfx;


        logit need riskw `controls' [pw=weight], cluster(cgroup);
        mfx;

  
	/* Table 10 - lower half */        
        logit need sloan gdep `controls' [pw=weight], cluster(cgroup);
        mfx;
        testparm sloan gdep;

        logit need sloan liq `controls' [pw=weight], cluster(cgroup);
        mfx;
        testparm sloan liq;

        logit need gdep liq `controls' [pw=weight], cluster(cgroup);
        mfx;
        testparm gdep liq;

        logit need sloan gdep liq  `controls' [pw=weight], cluster(cgroup);
        mfx;
        testparm sloan gdep liq ;








